==> Paws-0.27.tar.gz: Paws-0.27/lib/Paws/SQS/PurgeQueue.pm <==

package Paws::SQS::PurgeQueue;
  use Moose;
  has QueueUrl => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'PurgeQueue');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SQS::PurgeQueue - Arguments for method PurgeQueue on Paws::SQS

=head1 DESCRIPTION

This class represents the parameters used for calling the method PurgeQueue on the 
Amazon Simple Queue Service service. Use the attributes of this class
as arguments to method PurgeQueue.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to PurgeQueue.

As an example:

  $service_obj->PurgeQueue(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> QueueUrl => Str

The queue URL of the queue to delete the messages from when using the
C<PurgeQueue> API.

Queue URLs are case-sensitive.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method PurgeQueue in L<Paws::SQS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.36.tar.gz: Paws-0.36/lib/Paws/SQS/PurgeQueue.pm <==

package Paws::SQS::PurgeQueue;
  use Moose;
  has QueueUrl => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'PurgeQueue');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SQS::PurgeQueue - Arguments for method PurgeQueue on Paws::SQS

=head1 DESCRIPTION

This class represents the parameters used for calling the method PurgeQueue on the 
Amazon Simple Queue Service service. Use the attributes of this class
as arguments to method PurgeQueue.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to PurgeQueue.

As an example:

  $service_obj->PurgeQueue(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> QueueUrl => Str

The URL of the queue from which the C<PurgeQueue> action deletes
messages.

Queue URLs are case-sensitive.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method PurgeQueue in L<Paws::SQS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
